import { PDFDocumentProxy } from "pdfjs-dist";
import "pdfjs-dist/web/pdf_viewer.css";
import React, { Component } from "react";
import "../style/pdf_viewer.css";
import { BoundingRect, EventBus as EventBusType, LinkService as LinkServiceType, NormalizedPosition, Position, Viewer as ViewerType } from "../types";
export declare type Coords = {
    x: number;
    y: number;
};
export declare type TextSelectionType = {
    text: string;
    position: Position;
};
export declare type AreaSelectionType = {
    image: string;
    position: Position;
};
export declare type SelectionType = TextSelectionType | AreaSelectionType;
export declare type NormalizedTextSelection = {
    text: string;
    position: NormalizedPosition;
};
export declare type NormalizedAreaSelection = {
    image: string;
    position: NormalizedPosition;
};
export declare type NormalizedSelection = NormalizedTextSelection | NormalizedAreaSelection;
interface PdfViewerProps {
    pdfDocument: PDFDocumentProxy;
    selections?: Array<SelectionType>;
    enableAreaSelection?: (event: React.MouseEvent) => boolean;
    onTextSelection?: (highlightTip?: NormalizedTextSelection) => void;
    onAreaSelection?: (highlightTip?: NormalizedAreaSelection) => void;
}
interface PdfViewerState {
    containerNode?: HTMLDivElement;
    viewer?: ViewerType;
    pageHeights: number[];
    pageMargin: number;
    textSelectionEnabled: boolean;
    areaSelection?: {
        originTarget?: HTMLElement;
        start?: Coords;
        position?: NormalizedPosition;
        locked?: boolean;
    };
}
export declare class PdfViewer extends Component<PdfViewerProps, PdfViewerState> {
    state: PdfViewerState;
    eventBus: EventBusType;
    linkService: LinkServiceType;
    pdfContainerRefCallback: (ref: HTMLDivElement) => void;
    getPageOffset: (pageNumber: number) => number;
    containerCoords: (pageX: number, pageY: number) => {
        x: number;
        y: number;
    } | undefined;
    getBoundingRect(start: Coords, end: Coords): BoundingRect;
    rectsToLayout: (page: {
        node: HTMLElement;
        number: number;
    }, rects: BoundingRect[]) => {
        left: number;
        top: number;
        width: number;
        height: number;
    }[];
    resize: () => void;
    resetSelections: () => void;
    onSelectionChange: () => void;
    onAreaSelectStart: (event: React.MouseEvent) => void;
    getAreaSelectionPosition: (event: MouseEvent) => NormalizedPosition | undefined;
    onAreaSelectChange: (event: MouseEvent) => void;
    onAreaSelectEnd: (event: MouseEvent) => void;
    onMouseDown: (event: React.PointerEvent<HTMLDivElement>) => void;
    onMouseMove: (event: MouseEvent) => void;
    onMouseUp: (event: MouseEvent) => void;
    onKeyDown: (event: KeyboardEvent) => void;
    addEventListeners: () => void;
    removeEventListeners: () => void;
    componentDidUpdate(prevProps: PdfViewerProps): void;
    mountDocument: () => void;
    getPageViewport: (pageNumber: number) => {
        pageOffset: number;
        width: number;
        height: number;
        scale: number;
        transforms: number[];
        clone(options: import("pdfjs-dist").PDFPageViewportOptions): import("pdfjs-dist").PDFPageViewport;
        convertToViewportPoint(x: number, y: number): number[];
        convertToViewportRectangle(rect: number[]): number[];
        convertToPdfPoint(x: number, y: number): number[];
    } | undefined;
    renderSelection: (selection: SelectionType, i: number) => JSX.Element | null;
    render: () => JSX.Element;
}
export {};
